from setuptools import setup

setup(
        name="fc_digdata991",
        version="1.0",
        py_modules="fc_xd_bigdata3",
        author= "大数据3",
        author_email="2294090178@digadta.com",
        aescription="大数据3"
)


